# Changelog

## [0.2.12a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.12a1) (2025-12-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.11...0.2.12a1)

**Merged pull requests:**

- chore: Configure Renovate [\#65](https://github.com/OpenVoiceOS/ovos-PHAL/pull/65) ([renovate[bot]](https://github.com/apps/renovate))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
